@@ -1,4 +1,3 @@
-
 from enum import Enum
 from typing import Any
 
@@ -6,16 +5,17 @@ __all__ = ["Priority", "convert_to_priority"]
 
 # TODO: Why enum class cannot use classmethod attribute?
 
+
 class Priority(Enum):
-    CRITICAL = 1,
-    HIGH = 2,
-    MIDDLE = 3,
-    LOW = 4,
+    CRITICAL = (1,)
+    HIGH = (2,)
+    MIDDLE = (3,)
+    LOW = (4,)
     NA = 5
 
     def __str__(self) -> str:
-        if self.name == 'NA':
-            return 'N/A'
+        if self.name == "NA":
+            return "N/A"
         return self.name.capitalize()
 
     def __lt__(self, __o: object) -> bool:
@@ -44,14 +44,14 @@ class Priority(Enum):
 
 def convert_to_priority(raw: Any) -> Priority:
     raw = str(raw).strip().upper()
-    if raw == 'N/A':
+    if raw == "N/A":
         return Priority.NA
-    elif raw == 'LOW':
+    elif raw == "LOW":
         return Priority.LOW
-    elif raw == 'MEDIUM':
+    elif raw == "MEDIUM":
         return Priority.MIDDLE
-    elif raw == 'HIGH':
+    elif raw == "HIGH":
         return Priority.HIGH
-    elif raw == 'CRITICAL':
+    elif raw == "CRITICAL":
         return Priority.CRITICAL
     return Priority.NA
